import QtQuick 2.7
import QtQuick.Controls 2.2
import QtQuick.Layouts 1.12
import AppStyle 1.0
import AppControls 1.0
import Keyboard 1.0

Item {
    id: configItem

    Rectangle {
        anchors {
            top: parent.top
            left: parent.left
            right: parent.right
            bottom: configKeyboard.visible ? configKeyboard.top : footer.top
            bottomMargin: 15
        }

        color: "transparent"

        ScrollView {
            id: licenseScrollView
            anchors.fill: parent
            clip: true

            ScrollBar.vertical: ScrollBar {
                id: scroll
                policy: ScrollBar.AlwaysOn
                visible: true
                parent: licenseScrollView
                interactive: true
                anchors {
                    top: parent.top
                    left: parent.right
                    bottom: parent.bottom
                }

                contentItem: Rectangle {
                    implicitWidth: 7
                    implicitHeight: 100
                    color: scroll.pressed ? AppStyle.textColor : AppStyle.foreground
                }
            }

            RowLayout {
                id: textRow
                anchors.fill: parent
                clip: true
                spacing: 15
                ListView {
                    Layout.preferredWidth: 30
                    Layout.fillHeight: true
                    model: configText.text.split(/\n/g)
                    delegate:  Text {
                        font.pixelSize: 20
                        color: AppStyle.greyLine
                        text: index + 1
                    }
                }
                TextEdit {
                    id: configText
                    color: AppStyle.textColor
                    font.pixelSize: 20
                    Layout.fillWidth: true
                    Layout.fillHeight: true
                    onFocusChanged: {
                        if (focus) {
                            configKeyboard.visible = true
                            return
                        }
                        configKeyboard.visible = false
                    }
                }
            }
        }
    }

    Component.onCompleted: {
        rootItem.hideHead()
        configText.text = coreModel.сonfigToEdit
    }

    Keyboard {
        id: configKeyboard
        height: configKeyboard.visible ? parent.height * 0.6 : 1
        keyHeight: configKeyboard.visible ? height / 4 : 0
        visible: false
        z: 10
        anchors {
            left: parent.left
            right: parent.right
            bottom: parent.bottom
        }

        onEnterClicked: {
            configKeyboard.visible = false
            configText.focus = false
        }

        onKeyClicked: {

            if (key === '\b') {
                configText.remove(configText.cursorPosition - 1, configText.cursorPosition)
                return
            }
            configText.insert(configText.cursorPosition, key)

        }

        Behavior on height { PropertyAnimation { duration: 250 } }
    }

    Footer {
        id: footer
        nextBtnVisible: true
        nextBtnText: qsTr("Save")
        anchors {
            bottom: parent.bottom
            right: parent.right
            left: parent.left
        }
        onBackClicked: {
            rootItem.showHead()
            rootItem.back()
        }
        onNextClicked: {
            coreModel.validateAndSaveConfig(configText.text)
        }
    }
}
