import QtQuick 2.7
import QtQuick.Controls 2.4
import AppStyle 1.0

Item {

    signal gcodeResponse(string line, bool success)

    onGcodeResponse: {
        var output =
        consoleOutputText.text += success + " " + line + "\n"
    }

    Component.onCompleted: {
        printerModel.localModeOn()
        printerModel.enableResponseCallbacks()
        printerModel.onOn_responseCallback.connect(gcodeResponse)
    }

    Component.onDestruction: {
        printerModel.localModeOff()
        printerModel.disableResponseCallbacks()
        printerModel.onOn_responseCallback.disconnect(gcodeResponse)
    }

    Item {
        anchors {
            top: parent.top
            left: parent.left
            right: parent.right
            bottom: footer.top
        }

        ScrollView {
            id: consoleScrollView
            anchors {
                top: parent.top
                left: parent.left
                right: parent.right
                bottom: consoleTextField.top
                bottomMargin: AppStyle.defaultMargin * 0.5
            }

            ScrollBar.vertical: ScrollBar {
                id: scroll
                policy: ScrollBar.AlwaysOn
                visible: true
                parent: consoleScrollView
                interactive: true
                anchors {
                    top: parent.top
                    left: parent.right
                    bottom: parent.bottom
                }

                contentItem: Rectangle {
                    implicitWidth: 7
                    implicitHeight: 100
                    color: scroll.pressed ? AppStyle.textColor : AppStyle.foreground
                }
            }

            TextArea {
                id: consoleOutputText
                readOnly: true
                wrapMode: Text.WordWrap
                color: AppStyle.textColor


            }
        }

        TextField {
            id: consoleTextField
            anchors {
                left: parent.left
                right: parent.right
                bottom: parent.bottom
            }

            onAccepted: {
                if (consoleTextField.text === "") {
                    return
                }
                console.log(consoleTextField)
                printerModel.executeGcodeLine(consoleTextField.text)
                consoleTextField.text = ""
            }
        }
    }
    Footer {
        id: footer
        nextBtnVisible: false
        anchors {
            bottom: parent.bottom
            right: parent.right
            left: parent.left
        }
        onBackClicked: {
            rootItem.back()
        }
    }
}
