// Copyright 3D Control Systems, Inc. All Rights Reserved 2017-2019.
// Built in San Francisco.

// This software is distributed under a commercial license for personal,
// educational, corporate or any other use.
// The software as a whole or any parts of it is prohibited for distribution or
// use without obtaining a license from 3D Control Systems, Inc.

// All software licenses are subject to the 3DPrinterOS terms of use
// (available at https://www.3dprinteros.com/terms-and-conditions/),
// and privacy policy (available at https://www.3dprinteros.com/privacy-policy/)

import QtQuick 2.0
import QtQuick.XmlListModel 2.0
import AppStyle 1.0

Item {
    id: root

    property string source: "keyboard_us.xml"
    property int keyWidth: 75
    property int keyHeight: 100
    property int bounds: 2
    property alias mainFont: proxyMainTextItem.font
    property alias mainFontColor: proxyMainTextItem.color
    property alias secondaryFont: proxySecondaryTextItem.font
    property alias secondaryFontColor: proxySecondaryTextItem.color
    property color keyColor: "#474747"
    property color keyPressedColor: AppStyle.foreground


    property int xmlIndex: 1

    property bool allUpperCase: false

    signal keyClicked(string key)
    signal switchSource(string source)
    signal enterClicked()

    Text {
        id: proxyMainTextItem
        color: "#F2F2F2"
        font.pixelSize: root.height > 0 ? keyHeight * 0.4 : 30
        font.weight: Font.Light
        font.family: "Roboto"
        font.capitalization: root.allUpperCase ? Font.AllUppercase :
                                                 Font.MixedCase
        verticalAlignment: Text.AlignVCenter
        horizontalAlignment: Text.AlignHCenter
    }

    Text {
        id: proxySecondaryTextItem
        color: "#95A5A6"
        font.pointSize: root.height > 0 ? keyHeight * 0.4 : 20
        font.weight: Font.Light
        font.capitalization: root.allUpperCase ? Font.AllUppercase :
                                                 Font.MixedCase
        verticalAlignment: Text.AlignVCenter
        horizontalAlignment: Text.AlignHCenter
    }

    Column {
        id: column
        anchors.centerIn: parent

        Repeater {
            id: rowRepeater
            model: XmlListModel {
                source: root.source
                query: "/Keyboard/Row"
            }

            Row {
                id: keyRow
                property int rowIndex: index
                anchors.horizontalCenter: if(parent) parent.horizontalCenter

                Repeater {
                    id: keyRepeater
                    
                    model: XmlListModel {
                        source: root.source
                        query: "/Keyboard/Row[" + (rowIndex + 1) + "]/Key"

                        XmlRole { name: "labels"; query: "@labels/string()" }
                        XmlRole { name: "ratio"; query: "@ratio/number()" }
                        XmlRole { name: "icon"; query: "@icon/string()" }
                        XmlRole { name: "checkable"; query: "@checkable/string()" }
                    }

                    Key {
                        id: key
                        width: keyWidth * ratio
                        height: keyHeight
                        iconSource: icon
                        mainFont: proxyMainTextItem.font
                        mainFontColor: proxyMainTextItem.color
                        secondaryFont: proxySecondaryTextItem.font
                        secondaryFontColor: proxySecondaryTextItem.color
                        keyColor: root.keyColor
                        keyPressedColor: root.keyPressedColor
                        bounds: root.bounds
                        isChekable: checkable
                        isChecked: isChekable &&
                                   command &&
                                   command === "shift" &&
                                   allUpperCase

                        property var command
                        property var params: labels

                        onParamsChanged: {
                            var labelSplit = params.split(/[|]+/)

                            mainLabel = params.split(/[!|]+/)[0].toString();
                            if (labelSplit[1]) secondaryLabels = labelSplit[1];
                            command = params.split(/[!]+/)[1];
                        }

                        onClicked: {
                            console.log()
                            if (command)
                            {

                                var commandList = command.split(":");
                                switch(commandList[0])
                                {
                                    case "source":
                                        root.switchSource(commandList[1])
                                        return;
                                    case "shift":
                                        root.allUpperCase = !root.allUpperCase
                                        return;
                                    case "backspace":
                                        root.keyClicked('\b');
                                        return;
                                    case "enter":
                                        root.enterClicked()
                                        return;
                                    case "tab":
                                        root.keyClicked('\t');
                                        return;
                                    default: return;
                                }
                            }
                            if (mainLabel.length === 1)
                                root.emitKeyClicked(mainLabel);
                        }
                        onAlternatesClicked: root.emitKeyClicked(symbol);
                    }
                }
            }
        }
    }

    function emitKeyClicked(text) {
        keyClicked( allUpperCase ? text.toUpperCase() : text);
    }
}
